@@ -1,3 +1,3 @@
-# -*- coding: utf-8 -*-
 from .galaxy_fds_client import GalaxyFDSClient
 from .galaxy_fds_client_exception import GalaxyFDSClientException
+from .fds_client_configuration import FDSClientConfiguration
