@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
 class Common(object):
-  """There are common strings for FDS."""
-
   XIAOMI_HEADER_PREFIX = "x-xiaomi-"
   XIAOMI_HEADER_DATE = "x-xiaomi-date"
 
@@ -13,13 +10,15 @@ class Common(object):
   CONTENT_MD5 = "content-md5"
   CONTENT_TYPE = "content-type"
   DATE = "date"
+  RANGE = 'range'
 
-  REQUEST_TIME_LIMIT = 900000
+  REQUEST_TIME_LIMIT = 900000 # 15min
 
   CACHE_CONTROL = "cache-control"
   CONTENT_ENCODING = "content-encoding"
   CONTENT_LENGTH = "content-length"
   LAST_MODIFIED = "last-modified"
+  UPLOAD_TIME = "upload-time"
 
   DEFAULT_FDS_SERVICE_BASE_URI = "http://files.fds.api.xiaomi.com/"
-  DEFAULT_CDN_SERVICE_URI = "http://cdn.fds.api.xiaomi.com/"
+  DEFAULT_CDN_SERVICE_URI = "http://cdn.fds.api.xiaomi.com/"
\ No newline at end of file
