@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
-
 class Error(Exception):
   pass
 
-
 class GalaxyFDSClientException(Error):
-  """GalaxyFDSClientException is used for the exception of FDS."""
-
   def __init__(self, message):
     self.message = message
+
+  def __str__(self):
+    if self.message:
+      return super.__str__(self) + ": " + str(self.message)
+    return super.__str__(self)
